# orquestra-forest

`orquestra-forest` is a [Zapata](https://www.zapatacomputing.com) library holding modules for integrating forest with [Orquestra](https://www.zapatacomputing.com/orquestra/).

## Overview

`orquestra-forest` is a Python module that provides converters that allow switching between objects from [PyQuil](https://github.com/rigetti/pyquil) and `orquestra-quantum`.
It can be used directly in Python or in an [Orquestra](https://www.orquestra.io) workflow.
For more details, see the [Orquestra Pyquil integration docs](http://docs.orquestra.io/other-resources/framework-integrations/pyquil/).

For more information regarding Orquestra and resources, please refer to the [Orquestra documentation](https://www.orquestra.io/docs).

## Installation

This repository can be installed using `pip`. Clone the repository, enter the main directory of orquestra-forest, and run `pip install -e .`. For development install, run `pip install -e '.[dev]'` instead.

## Development and contribution

You can find the development guidelines in the [`orquestra-quantum` repository](https://github.com/zapatacomputing/orquestra-quantum).
